@@ -1,5 +1,5 @@
 package Yahoo::Marketing::APT::Ad;
-# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2010 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -16,12 +16,15 @@ sub _user_setable_attributes {
     return ( qw/ 
                  ID
                  accountID
-                 adGroupID
                  adOptimizationWeight
                  clickThroughURLs
                  createTimestamp
+                 endDate
                  lastUpdateTimestamp
+                 legacyAdGroupID
                  libraryAdID
+                 placementID
+                 startDate
                  status
                  type
             /  );
@@ -40,7 +43,7 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://help.yahoo.com/l/us/yahoo/apt/webservices/reference/data/> for documentation of the various data objects.
+See L<http://help.yahoo.com/l/us/yahoo/ewsapt/webservices/reference/data/> for documentation of the various data objects.
 
 
 =cut
@@ -57,12 +60,15 @@ Creates a new instance
 
     ID
     accountID
-    adGroupID
     adOptimizationWeight
     clickThroughURLs
     createTimestamp
+    endDate
     lastUpdateTimestamp
+    legacyAdGroupID
     libraryAdID
+    placementID
+    startDate
     status
     type
 
