@@ -1,5 +1,5 @@
 package Yahoo::Marketing::APT::LibraryCustomHTMLAd;
-# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2010 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -18,7 +18,7 @@ sub _user_setable_attributes {
                  accountID
                  adFormat
                  adSizeID
-                 associatedToAdGroup
+                 associatedToPlacement
                  createTimestamp
                  creativeIDs
                  editorialStatus
@@ -47,7 +47,7 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://help.yahoo.com/l/us/yahoo/apt/webservices/reference/data/> for documentation of the various data objects.
+See L<http://help.yahoo.com/l/us/yahoo/ewsapt/webservices/reference/data/> for documentation of the various data objects.
 
 
 =cut
@@ -66,7 +66,7 @@ Creates a new instance
     accountID
     adFormat
     adSizeID
-    associatedToAdGroup
+    associatedToPlacement
     createTimestamp
     creativeIDs
     editorialStatus
