@@ -1,5 +1,5 @@
 package Yahoo::Marketing::APT::Order;
-# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2010 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -27,6 +27,7 @@ sub _user_setable_attributes {
                  externalOrderID
                  grossCost
                  internalComments
+                 isBillOnThirdParty
                  isInternal
                  lastUpdateTimestamp
                  name
@@ -51,7 +52,7 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://help.yahoo.com/l/us/yahoo/apt/webservices/reference/data/> for documentation of the various data objects.
+See L<http://help.yahoo.com/l/us/yahoo/ewsapt/webservices/reference/data/> for documentation of the various data objects.
 
 
 =cut
@@ -79,6 +80,7 @@ Creates a new instance
     externalOrderID
     grossCost
     internalComments
+    isBillOnThirdParty
     isInternal
     lastUpdateTimestamp
     name
