@@ -1,5 +1,5 @@
 package Yahoo::Marketing::APT::Placement;
-# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2010 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -16,20 +16,25 @@ sub _user_setable_attributes {
     return ( qw/ 
                  ID
                  accountID
-                 adGroupID
+                 adAttributes
+                 adOptimization
                  comments
+                 contentTargetingAttributes
                  createTimestamp
-                 discounts
                  endDate
-                 guaranteedSettings
+                 guaranteedPriceSettings
+                 inventorySearchFilter
                  lastUpdateTimestamp
-                 nonGuaranteedSettings
+                 name
+                 nonGuaranteedPriceSettings
+                 orderID
+                 revenueCategory
                  revisedFromPlacementID
                  revisedToPlacementID
                  startDate
                  status
-                 transferedFromPlacementID
-                 transferedToPlacementID
+                 transferredFromPlacementID
+                 transferredToPlacementID
             /  );
 }
 
@@ -46,7 +51,7 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://help.yahoo.com/l/us/yahoo/apt/webservices/reference/data/> for documentation of the various data objects.
+See L<http://help.yahoo.com/l/us/yahoo/ewsapt/webservices/reference/data/> for documentation of the various data objects.
 
 
 =cut
@@ -63,20 +68,25 @@ Creates a new instance
 
     ID
     accountID
-    adGroupID
+    adAttributes
+    adOptimization
     comments
+    contentTargetingAttributes
     createTimestamp
-    discounts
     endDate
-    guaranteedSettings
+    guaranteedPriceSettings
+    inventorySearchFilter
     lastUpdateTimestamp
-    nonGuaranteedSettings
+    name
+    nonGuaranteedPriceSettings
+    orderID
+    revenueCategory
     revisedFromPlacementID
     revisedToPlacementID
     startDate
     status
-    transferedFromPlacementID
-    transferedToPlacementID
+    transferredFromPlacementID
+    transferredToPlacementID
 
 =back
 
